==> devops-client-java-1.0.2-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineSourceFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;

public interface V1alpha1PipelineSourceFluent<A extends V1alpha1PipelineSourceFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildCodeRepository instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1CodeRepositoryRef getCodeRepository();
    public V1alpha1CodeRepositoryRef buildCodeRepository();
    public A withCodeRepository(V1alpha1CodeRepositoryRef codeRepository);
    public Boolean hasCodeRepository();
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> withNewCodeRepository();
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> withNewCodeRepositoryLike(V1alpha1CodeRepositoryRef item);
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> editCodeRepository();
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> editOrNewCodeRepository();
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> editOrNewCodeRepositoryLike(V1alpha1CodeRepositoryRef item);
    
/**
 * This method has been deprecated, please use method buildGit instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSourceGit getGit();
    public V1alpha1PipelineSourceGit buildGit();
    public A withGit(V1alpha1PipelineSourceGit git);
    public Boolean hasGit();
    public V1alpha1PipelineSourceFluent.GitNested<A> withNewGit();
    public V1alpha1PipelineSourceFluent.GitNested<A> withNewGitLike(V1alpha1PipelineSourceGit item);
    public V1alpha1PipelineSourceFluent.GitNested<A> editGit();
    public V1alpha1PipelineSourceFluent.GitNested<A> editOrNewGit();
    public V1alpha1PipelineSourceFluent.GitNested<A> editOrNewGitLike(V1alpha1PipelineSourceGit item);
    
/**
 * This method has been deprecated, please use method buildSecret instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1SecretKeySetRef getSecret();
    public V1alpha1SecretKeySetRef buildSecret();
    public A withSecret(V1alpha1SecretKeySetRef secret);
    public Boolean hasSecret();
    public V1alpha1PipelineSourceFluent.SecretNested<A> withNewSecret();
    public V1alpha1PipelineSourceFluent.SecretNested<A> withNewSecretLike(V1alpha1SecretKeySetRef item);
    public V1alpha1PipelineSourceFluent.SecretNested<A> editSecret();
    public V1alpha1PipelineSourceFluent.SecretNested<A> editOrNewSecret();
    public V1alpha1PipelineSourceFluent.SecretNested<A> editOrNewSecretLike(V1alpha1SecretKeySetRef item);
    public String getSourceType();
    public A withSourceType(String sourceType);
    public Boolean hasSourceType();
    public A withNewSourceType(String arg1);
    public A withNewSourceType(StringBuilder arg1);
    public A withNewSourceType(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSvn instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSourceSvn getSvn();
    public V1alpha1PipelineSourceSvn buildSvn();
    public A withSvn(V1alpha1PipelineSourceSvn svn);
    public Boolean hasSvn();
    public V1alpha1PipelineSourceFluent.SvnNested<A> withNewSvn();
    public V1alpha1PipelineSourceFluent.SvnNested<A> withNewSvnLike(V1alpha1PipelineSourceSvn item);
    public V1alpha1PipelineSourceFluent.SvnNested<A> editSvn();
    public V1alpha1PipelineSourceFluent.SvnNested<A> editOrNewSvn();
    public V1alpha1PipelineSourceFluent.SvnNested<A> editOrNewSvnLike(V1alpha1PipelineSourceSvn item);

    public interface CodeRepositoryNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1CodeRepositoryRefFluent<V1alpha1PipelineSourceFluent.CodeRepositoryNested<N>>{

        
    public N and();    public N endCodeRepository();
}
    public interface GitNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceGitFluent<V1alpha1PipelineSourceFluent.GitNested<N>>{

        
    public N and();    public N endGit();
}
    public interface SecretNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1SecretKeySetRefFluent<V1alpha1PipelineSourceFluent.SecretNested<N>>{

        
    public N and();    public N endSecret();
}
    public interface SvnNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceSvnFluent<V1alpha1PipelineSourceFluent.SvnNested<N>>{

        
    public N and();    public N endSvn();
}


}

==> devops-client-java-1.0.6.1-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineSourceFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;

public interface V1alpha1PipelineSourceFluent<A extends V1alpha1PipelineSourceFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildCodeRepository instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1CodeRepositoryRef getCodeRepository();
    public V1alpha1CodeRepositoryRef buildCodeRepository();
    public A withCodeRepository(V1alpha1CodeRepositoryRef codeRepository);
    public Boolean hasCodeRepository();
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> withNewCodeRepository();
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> withNewCodeRepositoryLike(V1alpha1CodeRepositoryRef item);
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> editCodeRepository();
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> editOrNewCodeRepository();
    public V1alpha1PipelineSourceFluent.CodeRepositoryNested<A> editOrNewCodeRepositoryLike(V1alpha1CodeRepositoryRef item);
    
/**
 * This method has been deprecated, please use method buildDisk instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSourceDisk getDisk();
    public V1alpha1PipelineSourceDisk buildDisk();
    public A withDisk(V1alpha1PipelineSourceDisk disk);
    public Boolean hasDisk();
    public V1alpha1PipelineSourceFluent.DiskNested<A> withNewDisk();
    public V1alpha1PipelineSourceFluent.DiskNested<A> withNewDiskLike(V1alpha1PipelineSourceDisk item);
    public V1alpha1PipelineSourceFluent.DiskNested<A> editDisk();
    public V1alpha1PipelineSourceFluent.DiskNested<A> editOrNewDisk();
    public V1alpha1PipelineSourceFluent.DiskNested<A> editOrNewDiskLike(V1alpha1PipelineSourceDisk item);
    
/**
 * This method has been deprecated, please use method buildGit instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSourceGit getGit();
    public V1alpha1PipelineSourceGit buildGit();
    public A withGit(V1alpha1PipelineSourceGit git);
    public Boolean hasGit();
    public V1alpha1PipelineSourceFluent.GitNested<A> withNewGit();
    public V1alpha1PipelineSourceFluent.GitNested<A> withNewGitLike(V1alpha1PipelineSourceGit item);
    public V1alpha1PipelineSourceFluent.GitNested<A> editGit();
    public V1alpha1PipelineSourceFluent.GitNested<A> editOrNewGit();
    public V1alpha1PipelineSourceFluent.GitNested<A> editOrNewGitLike(V1alpha1PipelineSourceGit item);
    
/**
 * This method has been deprecated, please use method buildSecret instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1SecretKeySetRef getSecret();
    public V1alpha1SecretKeySetRef buildSecret();
    public A withSecret(V1alpha1SecretKeySetRef secret);
    public Boolean hasSecret();
    public V1alpha1PipelineSourceFluent.SecretNested<A> withNewSecret();
    public V1alpha1PipelineSourceFluent.SecretNested<A> withNewSecretLike(V1alpha1SecretKeySetRef item);
    public V1alpha1PipelineSourceFluent.SecretNested<A> editSecret();
    public V1alpha1PipelineSourceFluent.SecretNested<A> editOrNewSecret();
    public V1alpha1PipelineSourceFluent.SecretNested<A> editOrNewSecretLike(V1alpha1SecretKeySetRef item);
    public String getSourceType();
    public A withSourceType(String sourceType);
    public Boolean hasSourceType();
    public A withNewSourceType(String arg1);
    public A withNewSourceType(StringBuilder arg1);
    public A withNewSourceType(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSvn instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSourceSvn getSvn();
    public V1alpha1PipelineSourceSvn buildSvn();
    public A withSvn(V1alpha1PipelineSourceSvn svn);
    public Boolean hasSvn();
    public V1alpha1PipelineSourceFluent.SvnNested<A> withNewSvn();
    public V1alpha1PipelineSourceFluent.SvnNested<A> withNewSvnLike(V1alpha1PipelineSourceSvn item);
    public V1alpha1PipelineSourceFluent.SvnNested<A> editSvn();
    public V1alpha1PipelineSourceFluent.SvnNested<A> editOrNewSvn();
    public V1alpha1PipelineSourceFluent.SvnNested<A> editOrNewSvnLike(V1alpha1PipelineSourceSvn item);

    public interface CodeRepositoryNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1CodeRepositoryRefFluent<V1alpha1PipelineSourceFluent.CodeRepositoryNested<N>>{

        
    public N and();    public N endCodeRepository();
}
    public interface DiskNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceDiskFluent<V1alpha1PipelineSourceFluent.DiskNested<N>>{

        
    public N and();    public N endDisk();
}
    public interface GitNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceGitFluent<V1alpha1PipelineSourceFluent.GitNested<N>>{

        
    public N and();    public N endGit();
}
    public interface SecretNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1SecretKeySetRefFluent<V1alpha1PipelineSourceFluent.SecretNested<N>>{

        
    public N and();    public N endSecret();
}
    public interface SvnNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceSvnFluent<V1alpha1PipelineSourceFluent.SvnNested<N>>{

        
    public N and();    public N endSvn();
}


}
